<?php


namespace Fastrack\Settings;


use Fastrack\Property\WebBookingInterface;
use SilverStripe\CMS\Model\SiteTree;
use SilverStripe\Core\Environment;
use SilverStripe\Forms\FieldList;
use SilverStripe\Forms\HeaderField;
use SilverStripe\Forms\TextField;
use SilverStripe\Forms\TreeDropdownField;
use SilverStripe\ORM\DataExtension;

class ApiKeyExtension extends DataExtension
{

	private static array $db = [
		'GoogleMapAPIKey' => 'Varchar(255)',
		'GoogleMapAPIKeyServerSide' => 'Varchar(255)',
		'GoogleReCaptchaKey' => 'Varchar(255)',
		'GoogleReCaptchaSecretKey' => 'Varchar(255)',

		'WbiTheme' => 'Varchar(255)',
		'IntegrateEndpoint' => 'Varchar(255)',
		'IntegrateChannel' => 'Varchar(255)',
		'IntegrateClient' => 'Int',
	];

	private static array $has_one = [
		'PropertyAvailabilityPage' => SiteTree::class,
		'RoomAvailabilityPage' => SiteTree::class,
		'ExtrasPage' => SiteTree::class,
		'GuestDetailsPage' => SiteTree::class,
		'BookingConfirmationPage' => SiteTree::class,
		'TermsAndConditionsPage' => SiteTree::class,
	];

	public function updateCMSFields(FieldList $fields)
	{
		$fields->addFieldsToTab('Root.APIs', [
			HeaderField::create('GoogleMaps', 'Google Maps'),
			TextField::create('GoogleMapAPIKey', 'Google Maps API Key'),
			TextField::create('GoogleMapAPIKeyServerSide', 'Google Maps API Key (server side)'),
			HeaderField::create('GoogleReCaptcha', 'Google ReCaptcha'),
			TextField::create('GoogleReCaptchaKey', 'Google ReCaptcha Key'),
			TextField::create('GoogleReCaptchaSecretKey', 'Google ReCaptcha Secret Key'),
		]);
		if (WebBookingInterface::enabled()) {
			$this->addWebBookingInterfaceFields($fields);
		}
		$fields->findOrMakeTab('Root.APIs')->setTitle('APIs');
	}

	private function addWebBookingInterfaceFields(FieldList $fields)
	{
		$fields->addFieldsToTab('Root.APIs', [
			HeaderField::create('WbeHeader', 'Web Booking Interface'),
			TextField::create('WbiTheme', 'Theme'),
			TextField::create('IntegrateEndpoint'),
			TextField::create('IntegrateChannel'),
			TextField::create('IntegrateClient'),
			TreeDropdownField::create('PropertyAvailabilityPageID', 'Property availability page', SiteTree::class),
			TreeDropdownField::create('RoomAvailabilityPageID', 'room availability page', SiteTree::class),
			TreeDropdownField::create('ExtrasPageID', 'Extras page', SiteTree::class),
			TreeDropdownField::create('GuestDetailsPageID', 'Guest details page', SiteTree::class),
			TreeDropdownField::create('BookingConfirmationPageID', 'Booking confirmation page', SiteTree::class),
			TreeDropdownField::create('TermsAndConditionsPageID', 'Terms and conditions page', SiteTree::class),
		]);
	}


}
