<?php


namespace Fastrack\Settings;


use \DateTime;
use GuzzleHttp\Client;
use GuzzleHttp\TransferStats;
use SilverStripe\Control\Controller;
use SilverStripe\ORM\FieldType\DBDatetime;

class InstagramTokenController extends Controller
{

	private static $allowed_actions = [
		'getAccessToken',
		'handleRedirectUrl',
	];

	private static $url_handlers = [
		'$TokenName!/access-token' => 'getAccessToken',
		'$TokenName!/redirect-url' => 'handleRedirectUrl',
	];

	public function getAccessToken()
	{
		$token = $this->getToken();
		if (!$token->LongLivedAccessToken) {
			$token->saveLongLivedToken();
		}
		$maxTokenAge = $token->LongLivedAccessTokenAge / 2;
		$lastUpdated = new DateTime($token->getField('LongLivedAccessTokenUpdated'));
		$now = new DateTime();
		$age = ($now->getTimestamp() - $lastUpdated->getTimestamp());
		if ($age > $maxTokenAge) {
			$token->refreshAccessToken();
		}
		$this->getResponse()->setBody(json_encode([
			'accessCode' => $token->LongLivedAccessToken,
			'userId' => $token->UserId
		]));
		$this->getResponse()->addHeader("Content-type", "application/json");
		return $this->getResponse();
	}

	public function handleRedirectUrl()
	{
		$code = str_replace('#_', '', $this->request->getVar('code'));
		$token = $this->getToken();
		$token->saveToken($code);
	}

	/**
	 * @return InstagramToken|null
	 */
	private function getToken()
	{
		$tokenName = $this->getRequest()->param('TokenName');
		return InstagramToken::get()->find('UserName', $tokenName);
	}



}
